@@ -3,7 +3,7 @@ BEGIN {
   $App::DuckPAN::Web::AUTHORITY = 'cpan:DDG';
 }
 # ABSTRACT: Webserver for duckpan server
-$App::DuckPAN::Web::VERSION = '0.142';
+$App::DuckPAN::Web::VERSION = '0.143';
 use Moo;
 use DDG::Request;
 use DDG::Test::Location;
@@ -156,13 +156,13 @@ sub request {
 						utf8::encode $body if utf8::is_utf8 $body;
 						warn "Cannot use wrap_jsonp_callback and wrap_string callback at the same time!" if $rewrite->wrap_jsonp_callback && $rewrite->wrap_string_callback;
 						if ($rewrite->wrap_jsonp_callback && $rewrite->callback) {
-							$body = $rewrite->callback.'('.$body.');';
+							$body = $rewrite->callback.'('.$body.');' unless defined $rewrite->missing_envs;
 						}
 						elsif ($rewrite->wrap_string_callback && $rewrite->callback) {
 							$body =~ s/"/\\"/g;
 							$body =~ s/\n/\\n/g;
 							$body =~ s/\R//g;
-							$body = $rewrite->callback.'("'.$body.'");';
+							$body = $rewrite->callback.'("'.$body.'");' unless defined $rewrite->missing_envs;
 						}
 						$response->code($res->code);
 						$response->content_type($res->content_type);
@@ -394,7 +394,7 @@ App::DuckPAN::Web - Webserver for duckpan server
 
 =head1 VERSION
 
-version 0.142
+version 0.143
 
 =head1 AUTHOR
 
